@@ -21,6 +21,9 @@
  */
 
 #include <gnome.h>
+#include <libgnomevfs/gnome-vfs.h>
+#include <libgnomevfs/gnome-vfs-mime.h>
+
 #include "dryad.h"
 
 static void connect_debugger_signals (DryadApp *app);
@@ -37,21 +40,38 @@ static void attached_cb (GdfDebuggerClient *dbg, DryadApp *app);
 static void detached_cb (GdfDebuggerClient *dbg, DryadApp *app);
 
 gboolean
-dryad_load_debugger (DryadApp *app)
+dryad_load_debugger (DryadApp *app, const char *filename)
 {
-    char *iid;
-    iid = g_getenv ("GDF_BACKEND_ID");
-    if (!iid)
-        iid = "OAFIID:gdf:libdryad-debugger:bacdada7-c2c5-43c1-9d1e-64982c205fa4";
-    app->dbg = gdf_debugger_client_new (iid);
+    GnomeVFSURI *uri;
+    const char *mime_type;
+    char *path;
+    GdfDebuggerClientResult res;
+    
+    if (g_path_is_absolute (filename)) {
+        path = g_strdup (filename);
+    } else {
+        char *dir = g_get_current_dir ();
+        path = g_strdup_printf ("%s%c%s", dir, G_DIR_SEPARATOR, filename);
+        g_free (dir);
+    }
+    
+    uri = gnome_vfs_uri_new (path);
+    mime_type = gnome_vfs_get_mime_type (uri);
+    gnome_vfs_uri_unref (uri);
+
+    app->dbg = gdf_debugger_client_new_for_mime_type (mime_type);
     
     if (!app->dbg) {
         GtkWidget *app_widget;
         app_widget = glade_xml_get_widget (app->ui, "dryad_app");
         gnome_app_error (GNOME_APP (app_widget),
-                         _("Unable to start the GDF backend server.\n"
+                         _("Unable to start a GDF backend server for this "
+                           "mime type.\n"
                            "Make sure you installed gnome-debug in the "
-                           "correct location."));
+                           "correct \n"
+                           "location and that you are trying to debug "
+                           "a file with \n"
+                           "a mime-type that gnome-debug supports."));
         return FALSE;
     }
     
@@ -61,6 +81,21 @@ dryad_load_debugger (DryadApp *app)
 	connect_debugger_signals (app);
     dryad_ui_set_debuggers (app);
 
+    res = gdf_debugger_client_load_binary (app->dbg, path);
+    if (res == GDF_DEBUGGER_CLIENT_OK) {
+        gdf_debugger_client_set_breakpoint_function (app->dbg, 
+                                                     NULL, "main",
+                                                     NULL, NULL);
+        app->binary_name = g_strdup (filename);
+    } else {
+        GtkWidget *app_widget;
+        app_widget = glade_xml_get_widget (app->ui, "dryad_app");
+        gnome_app_error (GNOME_APP (app_widget), 
+                         _("Could not load file."));
+    }
+
+    g_free (path);
+
     return TRUE;
 }
 
@@ -108,6 +143,12 @@ program_loaded_cb (GdfDebuggerClient *dbg, DryadApp *app)
 	app_widget = glade_xml_get_widget (app->ui, "dryad_app");
 	gnome_app_flash (GNOME_APP (app_widget), _("Program loaded."));
 
+	btn = glade_xml_get_widget (app->ui, "mnu_unload");
+	gtk_widget_set_sensitive (btn, TRUE);
+	btn = glade_xml_get_widget (app->ui, "mnu_run");
+	gtk_widget_set_sensitive (btn, TRUE);
+	btn = glade_xml_get_widget (app->ui, "mnu_attach");
+	gtk_widget_set_sensitive (btn, TRUE);
 	btn = glade_xml_get_widget (app->ui, "unload_btn");
 	gtk_widget_set_sensitive (btn, TRUE);
 	btn = glade_xml_get_widget (app->ui, "run_btn");
@@ -125,6 +166,24 @@ program_unloaded_cb (GdfDebuggerClient *dbg, DryadApp *app)
 	app_widget = glade_xml_get_widget (app->ui, "dryad_app");
 	gnome_app_flash (GNOME_APP (app_widget), _("Program unloaded."));
 
+	btn = glade_xml_get_widget (app->ui, "mnu_unload");
+	gtk_widget_set_sensitive (btn, FALSE);
+	btn = glade_xml_get_widget (app->ui, "mnu_run");
+	gtk_widget_set_sensitive (btn, FALSE);
+	btn = glade_xml_get_widget (app->ui, "mnu_attach");
+	gtk_widget_set_sensitive (btn, FALSE);
+	btn = glade_xml_get_widget (app->ui, "mnu_stop");
+	gtk_widget_set_sensitive (btn, FALSE);
+	btn = glade_xml_get_widget (app->ui, "mnu_step_into");
+	gtk_widget_set_sensitive (btn, FALSE);
+	btn = glade_xml_get_widget (app->ui, "mnu_step_over");
+	gtk_widget_set_sensitive (btn, FALSE);
+	btn = glade_xml_get_widget (app->ui, "mnu_step_out");
+	gtk_widget_set_sensitive (btn, FALSE);
+	btn = glade_xml_get_widget (app->ui, "mnu_stack_up");
+	gtk_widget_set_sensitive (btn, FALSE);
+	btn = glade_xml_get_widget (app->ui, "mnu_stack_down");
+	gtk_widget_set_sensitive (btn, FALSE);
 	btn = glade_xml_get_widget (app->ui, "unload_btn");
 	gtk_widget_set_sensitive (btn, FALSE);
 	btn = glade_xml_get_widget (app->ui, "run_btn");
@@ -153,6 +212,20 @@ execution_started_cb (GdfDebuggerClient *dbg, DryadApp *app)
 	app_widget = glade_xml_get_widget (app->ui, "dryad_app");
 	gnome_app_flash (GNOME_APP (app_widget), _("Starting..."));
 
+	btn = glade_xml_get_widget (app->ui, "mnu_attach");
+	gtk_widget_set_sensitive (btn, FALSE);
+	btn = glade_xml_get_widget (app->ui, "mnu_stop");
+	gtk_widget_set_sensitive (btn, TRUE);
+	btn = glade_xml_get_widget (app->ui, "mnu_step_into");
+	gtk_widget_set_sensitive (btn, TRUE);
+	btn = glade_xml_get_widget (app->ui, "mnu_step_over");
+	gtk_widget_set_sensitive (btn, TRUE);
+	btn = glade_xml_get_widget (app->ui, "mnu_step_out");
+	gtk_widget_set_sensitive (btn, TRUE);
+	btn = glade_xml_get_widget (app->ui, "mnu_stack_up");
+	gtk_widget_set_sensitive (btn, TRUE);
+	btn = glade_xml_get_widget (app->ui, "mnu_stack_down");
+	gtk_widget_set_sensitive (btn, TRUE);
 	btn = glade_xml_get_widget (app->ui, "attach_btn");
 	gtk_widget_set_sensitive (btn, FALSE);
 	btn = glade_xml_get_widget (app->ui, "stop_btn");
@@ -177,6 +250,20 @@ execution_exited_cb (GdfDebuggerClient *dbg, gint exit_code, DryadApp *app)
 	app_widget = glade_xml_get_widget (app->ui, "dryad_app");
 	gnome_app_flash (GNOME_APP (app_widget), _("Program exited."));
 
+	btn = glade_xml_get_widget (app->ui, "mnu_attach");
+	gtk_widget_set_sensitive (btn, TRUE);
+	btn = glade_xml_get_widget (app->ui, "mnu_stop");
+	gtk_widget_set_sensitive (btn, FALSE);
+	btn = glade_xml_get_widget (app->ui, "mnu_step_into");
+	gtk_widget_set_sensitive (btn, FALSE);
+	btn = glade_xml_get_widget (app->ui, "mnu_step_over");
+	gtk_widget_set_sensitive (btn, FALSE);
+	btn = glade_xml_get_widget (app->ui, "mnu_step_out");
+	gtk_widget_set_sensitive (btn, FALSE);
+	btn = glade_xml_get_widget (app->ui, "mnu_stack_up");
+	gtk_widget_set_sensitive (btn, FALSE);
+	btn = glade_xml_get_widget (app->ui, "mnu_stack_down");
+	gtk_widget_set_sensitive (btn, FALSE);
 	btn = glade_xml_get_widget (app->ui, "attach_btn");
 	gtk_widget_set_sensitive (btn, TRUE);
 	btn = glade_xml_get_widget (app->ui, "stop_btn");
@@ -224,8 +311,10 @@ signal_termination_cb (GdfDebuggerClient *dbg,
 void 
 attached_cb (GdfDebuggerClient *dbg, DryadApp *app)
 {	
-    GtkWidget *btn;
-    
+    GtkWidget *btn;    
+
+    btn = glade_xml_get_widget (app->ui, "mnu_detach");
+	gtk_widget_set_sensitive (btn, TRUE);
     btn = glade_xml_get_widget (app->ui, "detach_btn");
 	gtk_widget_set_sensitive (btn, TRUE);
 }
@@ -235,6 +324,8 @@ detached_cb (GdfDebuggerClient *dbg, DryadApp *app)
 {	
     GtkWidget *btn;
     
+    btn = glade_xml_get_widget (app->ui, "mnu_detach");
+	gtk_widget_set_sensitive (btn, FALSE);
     btn = glade_xml_get_widget (app->ui, "detach_btn");
 	gtk_widget_set_sensitive (btn, FALSE);
 }
