@@ -24,7 +24,7 @@
 #define __COMMANDER_CALLBACKS_H__
 
 #include "dryad.h"
-gboolean dryad_load_debugger (DryadApp *app);
+gboolean dryad_load_debugger (DryadApp *app, const char *filename);
 void dryad_unload_debugger (DryadApp *app);
 
 #endif
