@@ -102,7 +102,9 @@ static gint window_delete_event_cb (GtkWidget *widget, GdkEvent *event,
 
 static DryadWindow windows [] = {
     { "breakpoint_window", N_("Breakpoint Manager") },
+#if 0
     { "source_viewer_window", N_("Source Viewer") },
+#endif
     { "output_window", N_("Output Terminal") },
     { "register_window", N_("Registers") },
     { "variable_window", N_("Variables") },
@@ -261,30 +263,57 @@ init_main_frame (DryadApp *app)
 	widget = glade_xml_get_widget (app->ui, "unload_btn");
 	gtk_signal_connect (GTK_OBJECT (widget), "clicked", 
 						GTK_SIGNAL_FUNC (unload_cb), (gpointer) app);
+	widget = glade_xml_get_widget (app->ui, "mnu_run");
+	gtk_signal_connect (GTK_OBJECT (widget), "activate", 
+                        GTK_SIGNAL_FUNC (run_cb), (gpointer) app);
 	widget = glade_xml_get_widget (app->ui, "run_btn");
 	gtk_signal_connect (GTK_OBJECT (widget), "clicked", 
 						GTK_SIGNAL_FUNC (run_cb), (gpointer) app);
+	widget = glade_xml_get_widget (app->ui, "mnu_attach");
+	gtk_signal_connect (GTK_OBJECT (widget), "activate", 
+						GTK_SIGNAL_FUNC (attach_cb), (gpointer) app);
 	widget = glade_xml_get_widget (app->ui, "attach_btn");
 	gtk_signal_connect (GTK_OBJECT (widget), "clicked", 
 						GTK_SIGNAL_FUNC (attach_cb), (gpointer) app);
+	widget = glade_xml_get_widget (app->ui, "mnu_detach");
+	gtk_signal_connect (GTK_OBJECT (widget), "activate", 
+						GTK_SIGNAL_FUNC (detach_cb), (gpointer) app);
 	widget = glade_xml_get_widget (app->ui, "detach_btn");
 	gtk_signal_connect (GTK_OBJECT (widget), "clicked", 
 						GTK_SIGNAL_FUNC (detach_cb), (gpointer) app);
+	widget = glade_xml_get_widget (app->ui, "mnu_stop");
+	gtk_signal_connect (GTK_OBJECT (widget), "activate", 
+						GTK_SIGNAL_FUNC (stop_cb), (gpointer) app);
 	widget = glade_xml_get_widget (app->ui, "stop_btn");
 	gtk_signal_connect (GTK_OBJECT (widget), "clicked", 
 						GTK_SIGNAL_FUNC (stop_cb), (gpointer) app);
+	widget = glade_xml_get_widget (app->ui, "mnu_step_into");
+	gtk_signal_connect (GTK_OBJECT (widget), "activate", 
+						GTK_SIGNAL_FUNC (step_into_cb), (gpointer) app);
 	widget = glade_xml_get_widget (app->ui, "step_into_btn");
 	gtk_signal_connect (GTK_OBJECT (widget), "clicked", 
 						GTK_SIGNAL_FUNC (step_into_cb), (gpointer) app);
+	widget = glade_xml_get_widget (app->ui, "mnu_step_over");
+	gtk_signal_connect (GTK_OBJECT (widget), "activate", 
+						GTK_SIGNAL_FUNC (step_over_cb), (gpointer) app);
 	widget = glade_xml_get_widget (app->ui, "step_over_btn");
 	gtk_signal_connect (GTK_OBJECT (widget), "clicked", 
 						GTK_SIGNAL_FUNC (step_over_cb), (gpointer) app);
+	widget = glade_xml_get_widget (app->ui, "mnu_step_out");
+	gtk_signal_connect (GTK_OBJECT (widget), "activate", 
+						GTK_SIGNAL_FUNC (step_out_cb), (gpointer) app);
 	widget = glade_xml_get_widget (app->ui, "step_out_btn");
 	gtk_signal_connect (GTK_OBJECT (widget), "clicked", 
 						GTK_SIGNAL_FUNC (step_out_cb), (gpointer) app);
+	widget = glade_xml_get_widget (app->ui, "mnu_stack_up");
+	gtk_signal_connect (GTK_OBJECT (widget), "activate", 
+						GTK_SIGNAL_FUNC (stack_up_cb), (gpointer) app);
 	widget = glade_xml_get_widget (app->ui, "stack_up_btn");
 	gtk_signal_connect (GTK_OBJECT (widget), "clicked", 
 						GTK_SIGNAL_FUNC (stack_up_cb), (gpointer) app);
+	widget = glade_xml_get_widget (app->ui, "mnu_stack_down");
+	gtk_signal_connect (GTK_OBJECT (widget), "activate", 
+						GTK_SIGNAL_FUNC (stack_down_cb), (gpointer) app);
 	widget = glade_xml_get_widget (app->ui, "stack_down_btn");
 	gtk_signal_connect (GTK_OBJECT (widget), "clicked", 
 						GTK_SIGNAL_FUNC (stack_down_cb), (gpointer) app);
@@ -574,8 +603,6 @@ typedef struct
 static gint
 load_file (FileSelectedIdleData *data)
 {
-    GdfDebuggerClientResult res;
-
     if (data->app->binary_name != NULL) {
         gdf_debugger_client_unload_binary (data->app->dbg);
         g_free (data->app->binary_name);
@@ -586,25 +613,7 @@ load_file (FileSelectedIdleData *data)
     if (data->app->dbg)
         dryad_unload_debugger (data->app);
 
-    if (!dryad_load_debugger (data->app)) {
-        return FALSE;
-    }   
-    
-    res = gdf_debugger_client_load_binary (data->app->dbg, 
-                                           data->filename);
-    if (res == GDF_DEBUGGER_CLIENT_OK) {
-        gdf_debugger_client_set_breakpoint_function (data->app->dbg, 
-                                                     NULL, "main",
-                                                     NULL, NULL);
-        data->app->binary_name = g_strdup (data->filename);
-    } else {
-        GtkWidget *app_widget;
-        app_widget = glade_xml_get_widget (data->app->ui, "dryad_app");
-        gnome_app_error (GNOME_APP (app_widget), 
-                         _("Could not load file."));
-    }
-
-    g_free (data->filename);
+    dryad_load_debugger (data->app, data->filename);
 
     return FALSE;
 }
