@@ -25,6 +25,6 @@
 
 void dryad_ui_init (DryadApp *app);
 void dryad_ui_destroy (DryadApp *app);
-void dryad_ui_set_commanders (DryadApp *app);
+void dryad_ui_set_debuggers (DryadApp *app);
 
 #endif
